<?php

// Exit if accessed directly
defined( 'ABSPATH' ) || exit;

class WCSS_Admin_Enqueue_Scripts {

	public function __construct() {
		add_action( 'admin_enqueue_scripts', array( $this, 'enqueue_scripts' ), 200 );
	}

	/**
	 * Load scripts and styles on only plugin screens.
	 *
	 * @param string $hook
	 */
	public function enqueue_scripts( $hook ) {
		if ( true !== apply_filters( 'wcss_load_admin_scripts', $this->is_admin_screen( $hook ), $hook ) ) {
			return;
		}

		/**
		 * Select2 v4.1.0-rc.0
		 *
		 * @link https://github.com/jasonday/printThis
		 */
		wp_enqueue_style( 'wcss-select2', WCSS_PLUGIN_URL . 'assets/libraries/select2/select2.min.css', array(), '4.1.0-rc.0' );
		wp_enqueue_script( 'wcss-select2', WCSS_PLUGIN_URL . 'assets/libraries/select2/select2.min.js', array(), '4.1.0-rc.0', true );

		/**
		 * printThis v2.0.0
		 *
		 * @link https://github.com/jasonday/printThis
		 */
		wp_enqueue_script( 'wcss-printthis', WCSS_PLUGIN_URL . 'assets/libraries/printThis/printThis.js', array(), '2.0.0', true );

		// Load plugin scripts
		wp_enqueue_style( 'wcss-admin', WCSS_PLUGIN_URL . 'assets/css/wcss-admin.css', array(), WCSS_PLUGIN_VER );
		wp_enqueue_script( 'wcss-admin', WCSS_PLUGIN_URL . 'assets/js/wcss-admin.js', array(), WCSS_PLUGIN_VER, true );
		wp_localize_script(
			'wcss-admin',
			'wcssAdminObj',
			array(
				'ajax_url'              => admin_url( 'admin-ajax.php?ver=' . rand( 1, 999999 ) ),
				'wc_ajax_url'           => WC_AJAX::get_endpoint( '%%endpoint%%' ),
				'text_cart_link_copied' => esc_html__( 'Cart Link Copied', 'woo-cart-share' ),
			)
		);

		// Run load admin view cart ajax if on correct page.
		if ( isset( $_GET['page'] ) && $_GET['page'] === 'woocommerce-cart-share_saved-cart' && isset( $_GET['cart_key'] ) ) {

			$load_admin_view_cart = "jQuery.ajax({
                url: wcssAdminObj.wc_ajax_url.toString().replace( '%%endpoint%%', 'wcss_load_admin_saved_cart_view' ),
                type: 'POST',
                data: {
                    'cart_key': '" . esc_html( $_GET['cart_key'] ) . "',
                },
            })
            .done(function( response ) {
                jQuery( '#wcss-cart' ).html( response );
                jQuery( '[name=\"wcss_send_saved_cart[body]\"]' ).val( response );
            });";
			wp_add_inline_script( 'wcss-admin', $load_admin_view_cart );

		}

		// Run load admin view cart ajax if on correct page.
		if ( isset( $_GET['page'] ) && $_GET['page'] === 'woocommerce-cart-share_shared-cart' && isset( $_GET['cart_key'] ) ) {

			$load_admin_view_cart = "jQuery.ajax({
                url: wcssAdminObj.wc_ajax_url.toString().replace( '%%endpoint%%', 'wcss_load_admin_shared_cart_view' ),
                type: 'POST',
                data: {
                    'cart_key': '" . esc_html( $_GET['cart_key'] ) . "',
                },
            })
            .done(function( response ) {
                jQuery( '#wcss-cart' ).html( response );
                jQuery( '[name=\"wcss_send_saved_cart[body]\"]' ).val( response );
            });";
			wp_add_inline_script( 'wcss-admin', $load_admin_view_cart );

		}
	}

	/**
	 * Check whether current screen is plugin admin screen or not.
	 *
	 * @param string $hook
	 * @return boolean Return true if current screen is plugin admin screen.
	 */
	private function is_admin_screen( $hook ) {
		if ( $hook == 'toplevel_page_woocommerce-cart-share'
		 || $hook == 'woo-cart-share_page_woocommerce-cart-share_saved-cart'
		 || $hook == 'woo-cart-share_page_woocommerce-cart-share_shared-cart'
		 || $hook == 'woo-cart-share_page_woocommerce-cart-share_share-support'
		 || $hook == 'woo-cart-share_page_woocommerce-cart-share_documentation' ) {
			return true;
		}

		return false;
	}

}

$wcss_admin_enqueue_scripts = new WCSS_Admin_Enqueue_Scripts();
