<?php

// Exit if accessed directly
defined( 'ABSPATH' ) || exit;

/**
 * Admin menu class
 */
class WCSS_Admin_Init {

	public function __construct() {
		add_action( 'admin_menu', array( $this, 'admin_menu' ) );

		// Shared cart list screen options.
		add_action( 'load-woo-cart-share_page_woocommerce-cart-share_shared-cart', array( 'WCSS_Admin_Shared_Cart_Table', 'add_screen_option' ) );
		add_filter( 'set-screen-option', array( 'WCSS_Admin_Shared_Cart_Table', 'set_screen_option' ), 10, 3 );

		// Saved cart list screen options.
		add_action( 'load-woo-cart-share_page_woocommerce-cart-share_saved-cart', array( 'WCSS_Admin_Saved_Cart_Table', 'add_screen_option' ) );
		add_filter( 'set-screen-option', array( 'WCSS_Admin_Saved_Cart_Table', 'set_screen_option' ), 10, 3 );

	}

	/**
	 * Add admin meni
	 */
	public function admin_menu() {
		$main_menus = array(
			'main_menu'      => array(
				'page_title'  => __( 'Woo Cart Share', 'woo-cart-share' ),
				'menu_title'  => __( 'Woo Cart Share', 'woo-cart-share' ),
				'capability'  => 'manage_options',
				'menu_slug'   => 'woocommerce-cart-share',
				'callback'    => array( $this, 'admin_setting_page' ),
				'icon_url'    => 'dashicons-cart',
				'position'    => 58,
			),
		);

		$sub_menus = array(
			'shared_cart'    => array(
				'parent_slug' => 'woocommerce-cart-share',
				'page_title'  => __( 'Shared Cart', 'woo-cart-share' ),
				'menu_title'  => __( 'Shared Cart', 'woo-cart-share' ),
				'capability'  => 'manage_options',
				'menu_slug'   => 'woocommerce-cart-share_shared-cart',
				'callback'    => array( $this, 'admin_shared_cart_page' ),
				'position'    => 20,
			),
			'saved_cart'     => array(
				'parent_slug' => 'woocommerce-cart-share',
				'page_title'  => __( 'Saved Cart', 'woo-cart-share' ),
				'menu_title'  => __( 'Saved Cart', 'woo-cart-share' ),
				'capability'  => 'manage_options',
				'menu_slug'   => 'woocommerce-cart-share_saved-cart',
				'callback'    => array( $this, 'admin_saved_cart_page' ),
				'position'    => 30,
			),
			'plugin_support' => array(
				'parent_slug' => 'woocommerce-cart-share',
				'page_title'  => __( 'Plugin Support', 'woo-cart-share' ),
				'menu_title'  => __( 'Plugin Support', 'woo-cart-share' ),
				'capability'  => 'manage_options',
				'menu_slug'   => 'woocommerce-cart-share_share-support',
				'callback'    => array( $this, 'admin_plugin_support_page' ),
				'position'    => 40,
			),
			'documentation'  => array(
				'parent_slug' => 'woocommerce-cart-share',
				'page_title'  => __( 'Documentation', 'woo-cart-share' ),
				'menu_title'  => __( 'Documentation', 'woo-cart-share' ),
				'capability'  => 'manage_options',
				'menu_slug'   => 'woocommerce-cart-share_documentation',
				'callback'    => array( $this, 'admin_documentation_page' ),
				'position'    => 100,
			),
		);

		/**
		 * Filter admin submenus.
		 *
		 * @since 2.2.0
		 *
		 * @param array $submenus Plugin submenus.
		 */
		$sub_menus = apply_filters( 'wcss_admin_submenus', $sub_menus );

		/**
		 * Filter admin menus.
		 *
		 * @since 3.0.0
		 *
		 * @param array $menus Plugin menus.
		 */
		$menus = apply_filters( 'wcss_admin_menus', array_merge( $main_menus, $sub_menus ) );

		foreach ( $menus as $menu ) {
			if ( isset( $menu['parent_slug'] ) && ! empty( $menu['parent_slug'] ) ) {
				add_submenu_page(
					$menu['parent_slug'],
					esc_html( $menu['page_title'] ),
					esc_html( $menu['menu_title'] ),
					$menu['capability'],
					$menu['menu_slug'],
					isset( $menu['callback'] ) ? $menu['callback'] : '',
					isset( $menu['position'] ) ? $menu['position'] : null
				);
			} else {
				add_menu_page(
					esc_html( $menu['page_title'] ),
					esc_html( $menu['menu_title'] ),
					$menu['capability'],
					$menu['menu_slug'],
					isset( $menu['callback'] ) ? $menu['callback'] : '',
					isset( $menu['icon_url'] ) ? $menu['icon_url'] : '',
					isset( $menu['position'] ) ? $menu['position'] : null
				);
			}
		}
	}

	/**
	 * Admin setting main page
	 */
	public function admin_setting_page() {
		require_once WCSS_PLUGIN_PATH . 'includes/admin/views/html-admin-settings-page.php';
	}

	/**
	 * Admin saved cart list and view page.
	 *
	 * @since 1.9.0
	 */
	public function admin_shared_cart_page() {

		if ( isset( $_GET['page'] ) && 'woocommerce-cart-share_shared-cart' === $_GET['page'] && isset( $_GET['cart_key'] ) ) {
			$shared_cart = wcss_get_shared_cart( $_GET['cart_key'] );
			$saved_cart  = wcss_get_saved_cart( $_GET['cart_key'] );

			require_once WCSS_PLUGIN_PATH . 'includes/admin/views/html-admin-cart-view.php';
		} else {
			require_once WCSS_PLUGIN_PATH . 'includes/admin/views/html-admin-shared-cart-list.php';
		}
	}
	/**
	 * Admin saved cart list and view page.
	 */
	public function admin_saved_cart_page() {

		if ( isset( $_GET['page'] ) && 'woocommerce-cart-share_saved-cart' === $_GET['page'] && isset( $_GET['cart_key'] ) ) {
			$shared_cart = wcss_get_shared_cart( $_GET['cart_key'] );
			$saved_cart  = wcss_get_saved_cart( $_GET['cart_key'] );

			require_once WCSS_PLUGIN_PATH . 'includes/admin/views/html-admin-cart-view.php';
		} else {
			require_once WCSS_PLUGIN_PATH . 'includes/admin/views/html-admin-saved-cart-list.php';
		}
	}

	/**
	 * Admin plugin support page.
	 */
	public function admin_plugin_support_page() {
		require_once WCSS_PLUGIN_PATH . 'includes/admin/views/html-admin-support.php';
	}

	/**
	 * Documentation page.
	 *
	 * @since 1.8.3
	 */
	public function admin_documentation_page() {
		?>
		<div class="wrap">
			<iframe src="//docs.wecreativez.com/document/woocommerce-cart-share-and-save/"
				frameborder="0"
				scrolling="yes"
				width="100%"
				height="800">
			</iframe>
		</div>
		<?php
	}
}

$wcss_admin_init = new WCSS_Admin_Init();
