<?php
/**
 * Main setting page.
 *
 * @author  WeCreativez
 * @package WooCommerce Cart Share & Save
 * @version 1.8.5
 */

defined( 'ABSPATH' ) || exit; ?>

<div class="wrap">
	<h1><?php esc_html_e( 'WooCommerce Cart Share & Save', 'woo-cart-share' ); ?></h1>

	<?php settings_errors(); ?>

	<hr>

	<?php
	$active_tab = isset( $_GET['tab'] ) ? sanitize_text_field( wp_unslash( $_GET['tab'] ) ) : 'appearance';
	$tabs       = array(
		'appearance'                 => array(
			'label'   => __( 'Appearance', 'woo-cart-share' ),
			'display' => true,
		),
		'basic_settings'             => array(
			'label'   => __( 'Basic Settings', 'woo-cart-share' ),
			'display' => true,
		),
		'advanced_settings'          => array(
			'label'   => __( 'Advanced Settings', 'woo-cart-share' ),
			'display' => true,
		),
		'popup_text_settings'        => array(
			'label'   => __( 'Popup Text Settings', 'woo-cart-share' ),
			'display' => true,
		),
		'share_integration_settings' => array(
			'label'   => __( 'Share Integration', 'woo-cart-share' ),
			'display' => true,
		),
		'my_account_settings'        => array(
			'label'   => __( 'My Account', 'woo-cart-share' ),
			'display' => true,
		),
		'email_settings'             => array(
			'label'   => __( 'Email Settings', 'woo-cart-share' ),
			'display' => true,
		),
		'print_cart_settings'        => array(
			'label'   => __( 'Print Cart Settings', 'woo-cart-share' ),
			'display' => true,
		),
		'shortcodes'                 => array(
			'label'   => __( 'Shortcodes', 'woo-cart-share' ),
			'display' => true,
		),
		'preview_email_cart'         => array(
			'label'   => __( 'Preview Email Cart', 'woo-cart-share' ),
			'display' => false,
		),
		'developer_settings'         => array(
			'label'   => __( 'Developer Settings', 'woo-cart-share' ),
			'display' => false,
		),
	);

	/**
	 * Filter tabs.
	 *
	 * @since 2.0.2
	 */
	$tabs = apply_filters( 'wcss_admin_setting_tabs', $tabs );
	?>

<h2 class="nav-tab-wrapper">

	<?php foreach ( $tabs as $tab_id => $tab ) : ?>

		<?php if ( isset( $tab['display'] ) && true === $tab['display'] ) : ?>

			<a href="?page=woocommerce-cart-share&tab=<?php echo esc_attr( $tab_id ); ?>" id="<?php echo esc_attr( $tab_id ); ?>" class="nav-tab <?php echo $tab_id === $active_tab ? 'nav-tab-active' : ''; ?>">
				<?php echo esc_html( $tab['label'] ); ?>
			</a>

		<?php endif; ?>

	<?php endforeach; ?>

</h2>

<form method="POST" action="options.php" class="wcss-admin-form">

	<?php
	switch ( $active_tab ) {
		case 'appearance':
			WCSS_Settings::do_settings( 'wcss_appearance_settings' );
			submit_button();
			break;

		case 'basic_settings':
			WCSS_Settings::do_settings( 'wcss_basic_settings' );
			submit_button();
			break;

		case 'advanced_settings':
			WCSS_Settings::do_settings( 'wcss_advanced_settings' );
			submit_button();
			break;

		case 'popup_text_settings':
			WCSS_Settings::do_settings( 'wcss_popup_text_settings' );
			submit_button();
			break;

		case 'share_integration_settings':
			require_once WCSS_PLUGIN_PATH . 'includes/admin/views/html-admin-share-integration-settings.php';
			break;

		case 'my_account_settings':
			WCSS_Settings::do_settings( 'wcss_my_account_settings' );
			submit_button();
			break;

		case 'email_settings':
			WCSS_Settings::do_settings( 'wcss_email_settings' );
			submit_button();
			break;

		case 'print_cart_settings':
			WCSS_Settings::do_settings( 'wcss_print_cart_settings' );
			submit_button();
			break;

		case 'developer_settings':
			WCSS_Settings::do_settings( 'wcss_developer_settings' );
			submit_button();
			break;

		case 'shortcodes':
			require_once WCSS_PLUGIN_PATH . 'includes/admin/views/html-admin-shortcodes.php';
			break;
	}

	/**
	 * Hook admin settings page.
	 *
	 * @since 2.0.2
	 */
	do_action( 'wcss_admin_setting_tab_data', $active_tab, $tabs );
	?>

</form>

<div>
	<?php
		switch ( $active_tab ) {
			case 'preview_email_cart':
				require_once WCSS_PLUGIN_PATH . 'includes/admin/views/html-admin-preview-email-cart.php';
				break;
		}
	?>
</div>
