<?php

// Exit if accessed directly
defined( 'ABSPATH' ) || exit;

/**
 * WCSS_Enqueue_Scripts class responsable to load all the scripts and styles.
 */
class WCSS_Enqueue_Scripts {

	public function __construct() {
		add_action( 'wp_enqueue_scripts', array( $this, 'enqueue_scripts' ) );
	}

	/**
	 * Load all the required frontend scripts
	 *
	 * @return void
	 * @since 1.3
	 */
	public function enqueue_scripts() {
		// If current user has no access to share the cart then do nothing.
		if ( wcss_currnet_role_has_access() !== true ) {
			return;
		}

		/**
		 * clipboard.js v2.0.11
		 *
		 * @link https://zenorocha.github.io/clipboard.js
		 */
		wp_enqueue_script( 'wcss-clipboard', WCSS_PLUGIN_URL . 'assets/libraries/clipboard/clipboard.js', array(), '2.0.11', true );

		/**
		 * printThis v2.0.0
		 *
		 * @link https://github.com/jasonday/printThis
		 */
		wp_enqueue_script( 'wcss-printthis', WCSS_PLUGIN_URL . 'assets/libraries/printThis/printThis.js', array(), '2.0.0', true );

		// Plugin frontend scripts
		wp_enqueue_style( 'wcss-style', WCSS_PLUGIN_URL . 'assets/css/wcss-public.css', array(), WCSS_PLUGIN_VER );
		wp_enqueue_script( 'wcss-script', WCSS_PLUGIN_URL . 'assets/js/wcss-public.js', array(), WCSS_PLUGIN_VER, true );
		wp_localize_script(
			'wcss-script',
			'wcssObj',
			apply_filters( 'wcss_localize_script', array(
				'ajax_url'                     => admin_url( 'admin-ajax.php' ),
				'wc_ajax_url'                  => WC_AJAX::get_endpoint( '%%endpoint%%' ),
				'saved_cart_endpoint_url'      => wcss_get_saved_cart_endpoint_url(),
				'icons'                        => array(
					'check' => WCSS_Icons::get( 'check' ),
				),
				'print_cart_args'              => array(
					// PrintThis JS default arguments.
					'debug'                => false, // show the iframe for debugging
					'importCSS'            => false, // import parent page css
					'importStyle'          => false, // import style tags
					'printContainer'       => false, // grab outer container as well as the contents of the selector
					'loadCSS'              => array( // path to additional css file - use an array [] for multiple
						WCSS_PLUGIN_URL . 'assets/css/wcss-print-cart.css',
					),
					'pageTitle'            => '', // add title to print page
					'removeInline'         => false, // remove all inline styles from print elements
					'removeInlineSelector' => "body *", // custom selectors to filter inline styles. removeInline must be true
					'printDelay'           => 1000, // variable print delay
					'header'               => null, // prefix to html
					'footer'               => null, // postfix to html
					'base'                 => false, // preserve the BASE tag, or accept a string for the URL
					'formValues'           => true, // preserve input/form values
					'canvas'               => true, // copy canvas elements
					'removeScripts'        => true, // remove script tags from print content
					'copyTagClasses'       => false, // copy classes from the html & body tag
					'copyTagStyles'        => false, // copy styles from html & body tag (for CSS Variables)
					'beforePrintEvent'     => null, // callback function for printEvent in iframe
					'beforePrint'          => null, // function called before iframe is filled
					'afterPrint'           => null, // function called before iframe is removed

					// Custom arguments.
					'file_name'            => esc_html( get_option( 'wcss_print_cart_file_name' ) ),
				),
			) )
		);

		// Public inline style
		$css = '';

		$css .= '.wcss-popup {
			--popup-close-button-bg-color: ' . esc_html( get_option( 'wcss_popup_close_button_background_color' ) ) . ';
			--popup-close-button-icon-color: ' . esc_html( get_option( 'wcss_popup_close_button_icon_color' ) ) . ';
		}';

		$css .= '.wcss-popup--bg-color {
            background-color: ' . esc_html( get_option( 'wcss_popup_background_color' ) ) . ';
        }';
		$css .= '.wcss-popup--text-color {
            color: ' . esc_html( get_option( 'wcss_popup_text_color' ) ) . ';
        }';
		$css .= '.wcss-btn {
            background-color: ' . esc_html( get_option( 'wcss_button_background_color' ) ) . ' !important;
            color: ' . esc_html( get_option( 'wcss_button_text_color' ) ) . ' !important;
        }';

		$css .= wp_kses_post( get_option( 'wcss_custom_css' ) );

		wp_add_inline_style( 'wcss-style', $css );

	}


} // end of class WCSS_Enqueue_Scripts

$wcss_enqueue_scripts = new WCSS_Enqueue_Scripts();
