<?php

// Exit if accessed directly
defined( 'ABSPATH' ) || exit;

class WCSS_Print_Cart {

	public function __construct() {
		// Print cart Header, Footer and content hooks.
		add_action( 'wcss_print_cart_header', array( $this, 'print_cart_header' ), 10 );
		add_action( 'wcss_print_cart_details', array( $this, 'print_cart_retrieve_cart' ), 10 );
		add_action( 'wcss_print_cart_details', array( $this, 'print_cart_products' ), 20 );
		add_action( 'wcss_print_cart_details', array( $this, 'print_cart_totals' ), 30 );
		add_action( 'wcss_print_cart_details', array( $this, 'print_cart_follow_us' ), 40 );
		add_action( 'wcss_print_cart_footer', array( $this, 'print_cart_footer' ), 10 );

		// Hooks for printing cart via AJAX.
		add_action( 'wp_ajax_woocommerce_wcss_print_cart_ajax', array( $this, 'print_cart' ) );
		add_action( 'wp_ajax_woocommerce_nopriv_wcss_print_cart_ajax', array( $this, 'print_cart' ) );
		add_action( 'wc_ajax_wcss_print_cart_ajax', array( $this, 'print_cart' ) );

		add_filter( 'wcss_localize_script', array( $this, 'filter_print_cart_args' ) );

		// Let 3rd parties unhook the above via this hook.
		do_action( 'wcss_print_cart', $this  );
	}

	/**
	 * Print cart.
	 */
	public function print_cart() {
		global $wpdb, $woocommerce;

		$cart_key = sanitize_text_field( $_POST['print_cart_key'] );

		wcss_set_session_to_cart( $cart_key );

		// Calculate the complete cart, so that all the WooCommerce actions and hooks can run first.
		WC()->cart->calculate_totals();

		echo wcss_get_template_html(
			'print-cart/print-cart.php',
			array(
				'message'  => wp_kses_post( get_option( 'wcss_email_description' ) ),
				'cart_key' => $cart_key,
			)
		);

		wp_die();
	}

	/**
	 * Print cart arguments filter.
	 *
	 * @since 2.1.0
	 *
	 * @param array $print_cart_args Print cart arguments.
	 * @return array Filtered print cart args.
	 */
	public function filter_print_cart_args( $print_cart_args ) {
		if ( 'yes' === get_option( 'wcss_print_cart_website_style_status' ) ) {
			$print_cart_args['print_cart_args']['importCSS']      = true;
			$print_cart_args['print_cart_args']['importStyle']    = true;
			$print_cart_args['print_cart_args']['copyTagClasses'] = true;
			$print_cart_args['print_cart_args']['copyTagStyles']  = true;
		} else {
			$print_cart_args['print_cart_args']['loadCSS'][] = WCSS_PLUGIN_URL . 'assets/css/wcss-print-cart-reset.css';
		}

		if ( is_rtl() ) {
			$print_cart_args['print_cart_args']['copyTagClasses'] = true;
		}

		return $print_cart_args;
	}

	/**
	 * Print cart template header.
	 *
	 * @since 2.3.0
	 *
	 * @return void
	 */
	public function print_cart_header() {
		wcss_get_template( 'print-cart/header.php' );
	}

	/**
	 * Retrieve cart.
	 *
	 * @since 2.3.0
	 *
	 * @return void
	 */
	public function print_cart_retrieve_cart( $cart_key ) {
		wcss_get_template( 'print-cart/retrieve-cart.php', array( 'cart_key' => $cart_key ) );
	}

	/**
	 * List of products in current cart for print cart template.
	 *
	 * @since 2.3.0
	 *
	 * @return void
	 */
	public function print_cart_products() {
		wcss_get_template( 'print-cart/cart-products.php' );
	}

	/**
	 * Cart totals for print cart template.
	 *
	 * @since 2.3.0
	 *
	 * @return void
	 */
	public function print_cart_totals() {
		wcss_get_template( 'print-cart/cart-totals.php' );
	}

	/**
	 * Print cart follow us.
	 *
	 * @since 2.3.0
	 *
	 * @return void
	 */
	public function print_cart_follow_us() {
		wcss_get_template( 'print-cart/follow-us.php' );
	}

	/**
	 * Print cart template footer.
	 *
	 * @since 2.3.0
	 *
	 * @return void
	 */
	public function print_cart_footer() {
		wcss_get_template( 'print-cart/footer.php' );
	}
}

$wcss_print_cart = new WCSS_Print_Cart();
