<?php

// Exit if accessed directly
defined( 'ABSPATH' ) || exit;

class WCSS_Save_Cart {

	public function __construct() {
		add_action( 'init', array( $this, 'save_cart' ) );
		add_action( 'init', array( $this, 'delete_saved_cart' ) );

		add_action( 'wp_ajax_wcss_share_saved_cart_ajax', array( $this, 'share_saved_cart' ) );
		add_action( 'wp_ajax_nopriv_wcss_share_saved_cart_ajax', array( $this, 'share_saved_cart' ) );

		add_action( 'wp_ajax_wcss_save_cart_ajax', array( $this, 'save_cart' ) );
		add_action( 'wp_ajax_nopriv_wcss_save_cart_ajax', array( $this, 'save_cart' ) );

		add_action( 'init', array( $this, 'delete_saved_cart' ) );
	}

	/**
	 * Save user cart.
	 */
	public function save_cart() {
		if ( ! isset( $_POST['wcss_save_cart_nonce'] ) || ! wp_verify_nonce( $_POST['wcss_save_cart_nonce'], 'wcss_save_cart' ) ) {
			return;
		}

		if ( ! isset( $_POST['wcss_save_cart']['cart_key'] ) || ! isset( $_POST['wcss_save_cart']['cart_name'] ) ) {
			return;
		}

		$save_cart_args = array(
			'user_id'   => get_current_user_id(),
			'cart_key'  => sanitize_text_field( $_POST['wcss_save_cart']['cart_key'] ),
			'cart_name' => sanitize_text_field( $_POST['wcss_save_cart']['cart_name'] ),
		);

		/**
		 * Filter save cart arguments.
		 *
		 * @since 3.0.0
		 *
		 * @param array $save_cart_args Save cart arguments.
		 * @param array $post           POST data.
		 */
		$save_cart_args = apply_filters( 'wcss_save_cart_args', $save_cart_args, $_POST );

		$saved_cart = wcss_insert_saved_cart( $save_cart_args );

		/**
		 * Run action after save cart.
		 *
		 * @since 1.8.3
		 * @since 2.0.0 Added $saved_cart parameter.
		 *
		 * @param int    $saved_cart_id Inserted saved cart ID
		 * @param string $cart_key      Cart key
		 */
		do_action( 'wcss_after_save_cart', $saved_cart->get_id(), $save_cart_args['cart_key'], $saved_cart );

		wp_die();
	}

	/**
	 * Delete saved cart by user.
	 */

	public function delete_saved_cart() {
		if ( ! isset( $_GET['wcss_delete_saved_cart'] ) ) {
			return;
		}

		// Get cart_save_id and assign to variable
		$cart_key        = $_GET['wcss_delete_saved_cart'];
		$saved_cart      = wcss_get_saved_cart( $cart_key );
		$current_user_id = get_current_user_id();

		if ( $current_user_id !== $saved_cart->get_user_id() ) {
			return;
		}

		$saved_cart->delete();

		/**
		 * Run action after delete saved cart.
		 *
		 * @since 1.8.3
		 *
		 * @param string $cart_key          Cart key
		 * @param string $current_user_id   Current logged in user ID
		 */
		do_action( 'wcss_after_delete_saved_cart', $cart_key, $current_user_id );

		// Redirect on same page.
		wp_safe_redirect( apply_filters( 'wcss_delete_cart_redirection_url', wp_get_referer() ) );
	}

	/**
	 * Share saved cart.
	 */
	public function share_saved_cart() {

		$cart_key         = sanitize_text_field( $_POST['cart_key'] );
		$social_share_msg = esc_html( get_option( 'wcss_social_share_message' ) );
		$cart_share_link  = wcss_get_cart_link( $cart_key );

		// Replace {link} with actual link.
		$complied_msg = str_replace( '{link}', $cart_share_link, $social_share_msg );

		wcss_get_template(
			'share-medium.php',
			apply_filters(
				'wcss_share_mediums',
				array(
					'cart_key'         => $cart_key,
					'cart_share_link'  => $cart_share_link,
					'print_cart_key'   => $cart_key,
					'whatsapp_link'    => "https://wa.me/?text={$complied_msg}",
					'email_link'       => "mailto:?body={$complied_msg}",
					'facebook_link'    => 'https://www.facebook.com/sharer.php?u=' . urlencode( $cart_share_link ) . '',
					'twitter_link'     => "https://twitter.com/intent/tweet?url={$complied_msg}",
					'google_plus_link' => "https://plus.google.com/share?url={$complied_msg}",
					'skype_link'       => "https://web.skype.com/share?url={$complied_msg}",
					'messenger_link'   => "fb-messenger://share/?link={$complied_msg}",
				)
			)
		);

		wp_die();
	}


} // end of WCSS_Save_Cart

$wcss_save_cart = new WCSS_Save_Cart();
