<?php
/**
 * Register settings.
 *
 * @author  WeCreativez
 * @package WooCommerce Cart Share & Save
 * @version 2.0.0
 */

defined( 'ABSPATH' ) || exit;

require_once WCSS_PLUGIN_PATH  . 'includes/class-wcss-settings-api.php';

/**
 * Class WCSS_Settings.
 *
 * @since 2.0.0
 */
class WCSS_Settings extends WCSS_Settings_API  {

	/**
	 * Class constructor.
	 *
	 * @since 2.0.0
	 */
	public function __construct() {
		parent::init();

		add_filter( 'wcss_register_settings', array( $this, 'register_plugin_settings' ) );
		add_action( 'wcss_add_options', array( $this, 'add_plugin_options' ), 20, 2 );
		add_action( 'wcss_reset_options', array( $this, 'add_plugin_options' ), 20, 3 );

		add_action( 'admin_init', array( $this, 'legacy_register_settings' ) );
	}

	/**
	 * Register plugin settings.
	 *
	 * @since 2.0.0
	 *
	 * @param array $settings Settings array.
	 */
	public function register_plugin_settings( $settings ) {

		// Appearance settings - Popup Colors.
		$settings['wcss_appearance_settings'] = array(
			'id'     => 'wcss_appearance_settings',
			'title'  => __( 'Popup Colors & Settings', 'woo-cart-share' ),
			'fields' => array(
				'wcss_popup_background_color'        => array(
					'id'      => 'wcss_popup_background_color',
					'title'   => __( 'Popup Background Color', 'woo-cart-share' ),
					'type'    => 'color',
					'default' => '#ffffff',
					'desc'    => array(
						__( 'Change popup background color.', 'woo-cart-share' ),
						/* translators: %s: Hex color code of the popup background color. */
						sprintf( __( 'Default %s', 'woo-cart-share' ), '<code>#ffffff</code>' ),
					),
					'classes' => 'wcss-color-selector',
				),
				'wcss_popup_text_color'              => array(
					'id'      => 'wcss_popup_text_color',
					'title'   => __( 'Popup Text Color', 'woo-cart-share' ),
					'type'    => 'color',
					'default' => '#21234a',
					'desc'    => array(
						__( 'Change popup text color.', 'woo-cart-share' ),
						/* translators: %s: Hex color code of the popup text color. */
						sprintf( __( 'Default %s', 'woo-cart-share' ), '<code>#21234a</code>' ),
					),
					'classes' => 'wcss-color-selector',
				),
				'wcss_popup_text_color'              => array(
					'id'      => 'wcss_popup_close_button_background_color',
					'title'   => __( 'Close Button Background Color', 'woo-cart-share' ),
					'type'    => 'color',
					'default' => '#ff0000',
					'desc'    => array(
						__( 'Change close popup button background color.', 'woo-cart-share' ),
						/* translators: %s: Hex color code of the popup text color. */
						sprintf( __( 'Default %s', 'woo-cart-share' ), '<code>#ff0000</code>' ),
					),
					'classes' => 'wcss-color-selector',
				),
				'wcss_popup_close_button_icon_color' => array(
					'id'      => 'wcss_popup_close_button_icon_color',
					'title'   => __( 'Close Button Icon Color', 'woo-cart-share' ),
					'type'    => 'color',
					'default' => '#ffffff',
					'desc'    => array(
						__( 'Change close popup button icon color.', 'woo-cart-share' ),
						/* translators: %s: Hex color code of the popup text color. */
						sprintf( __( 'Default %s', 'woo-cart-share' ), '<code>#ffffff</code>' ),
					),
					'classes' => 'wcss-color-selector',
				),
				'wcss_popup_overlay_status'          => array(
					'id'      => 'wcss_popup_overlay_status',
					'type'    => 'checkbox',
					'title'   => __( 'Popup Overlay', 'woo-cart-share' ),
					'label'   => __( 'Enable/ Disable', 'woo-cart-share' ),
					'default' => 'yes',
				),
			),
		);

		// Appearance settings - Call to Action Colors.
		$settings['wcss_call_to_action_color_settings'] = array(
			'id'     => 'wcss_call_to_action_color_settings',
			'page'   => 'wcss_appearance_settings',
			'title'  => __( 'Call to Action Button Colors', 'woo-cart-share' ),
			'fields' => array(
				'wcss_button_background_color' => array(
					'id'      => 'wcss_button_background_color',
					'title'   => __( 'Buttons Background Color', 'woo-cart-share' ),
					'type'    => 'color',
					'default' => '#fc6c6c',
					'desc'    => array(
						__( 'Change buttons background color.', 'woo-cart-share' ),
						/* translators: %s: Hex color code of the button background color. */
						sprintf( __( 'Default %s', 'woo-cart-share' ), '<code>#fc6c6c</code>' ),
					),
					'classes' => 'wcss-color-selector',
				),
				'wcss_button_text_color'       => array(
					'id'      => 'wcss_button_text_color',
					'title'   => __( 'Buttons Text Color', 'woo-cart-share' ),
					'type'    => 'color',
					'default' => '#ffffff',
					'desc'    => array(
						__( 'Change buttons text color.', 'woo-cart-share' ),
						/* translators: %s: Hex color code of the button text color. */
						sprintf( __( 'Default %s', 'woo-cart-share' ), '<code>#ffffff</code>' ),
					),
					'classes' => 'wcss-color-selector',
				),
			),
		);

		// Appearance settings - Social Share Icon Colors.
		$settings['wcss_social_share_icon_color_settings'] = array(
			'id'     => 'wcss_social_share_icon_color_settings',
			'page'   => 'wcss_appearance_settings',
			'title'  => __( 'Social Share Icon Colors', 'woo-cart-share' ),
			'fields' => array(
				'wcss_email_icon_color_code'      => array(
					'id'      => 'wcss_email_icon_color_code',
					'title'   => __( 'Email Icon Color', 'woo-cart-share' ),
					'type'    => 'color',
					'default' => '#b92b27',
					'desc'    => array(
						__( 'Change the email icon color.', 'woo-cart-share' ),
						/* translators: %s: Hex color code of the popup background color. */
						sprintf( __( 'Default %s', 'woo-cart-share' ), '<code>#b92b27</code>' ),
					),
					'classes' => 'wcss-color-selector',
				),
				'wcss_whatsapp_icon_color_code'   => array(
					'id'      => 'wcss_whatsapp_icon_color_code',
					'title'   => __( 'WhatsApp Icon Color', 'woo-cart-share' ),
					'type'    => 'color',
					'default' => '#25d366',
					'desc'    => array(
						__( 'Change the WhatsApp icon color.', 'woo-cart-share' ),
						/* translators: %s: Hex color code of the popup background color. */
						sprintf( __( 'Default %s', 'woo-cart-share' ), '<code>#25d366</code>' ),
					),
					'classes' => 'wcss-color-selector',
				),
				'wcss_copy_link_icon_color_code'  => array(
					'id'      => 'wcss_copy_link_icon_color_code',
					'title'   => __( 'Copy Link Icon Color', 'woo-cart-share' ),
					'type'    => 'color',
					'default' => '#21759b',
					'desc'    => array(
						__( 'Change the copy link icon color.', 'woo-cart-share' ),
						/* translators: %s: Hex color code of the popup background color. */
						sprintf( __( 'Default %s', 'woo-cart-share' ), '<code>#21759b</code>' ),
					),
					'classes' => 'wcss-color-selector',
				),
				'wcss_facebook_icon_color_code'   => array(
					'id'      => 'wcss_facebook_icon_color_code',
					'title'   => __( 'Facebook Icon Color', 'woo-cart-share' ),
					'type'    => 'color',
					'default' => '#3b5999',
					'desc'    => array(
						__( 'Change the Facebook icon color.', 'woo-cart-share' ),
						/* translators: %s: Hex color code of the popup background color. */
						sprintf( __( 'Default %s', 'woo-cart-share' ), '<code>#3b5999</code>' ),
					),
					'classes' => 'wcss-color-selector',
				),
				'wcss_twitter_icon_color_code'    => array(
					'id'      => 'wcss_twitter_icon_color_code',
					'title'   => __( 'Twitter Icon Color', 'woo-cart-share' ),
					'type'    => 'color',
					'default' => '#55acee',
					'desc'    => array(
						__( 'Change the Twitter icon color.', 'woo-cart-share' ),
						/* translators: %s: Hex color code of the popup background color. */
						sprintf( __( 'Default %s', 'woo-cart-share' ), '<code>#55acee</code>' ),
					),
					'classes' => 'wcss-color-selector',
				),
				'wcss_skype_icon_color_code'      => array(
					'id'      => 'wcss_skype_icon_color_code',
					'title'   => __( 'Skype Icon Color', 'woo-cart-share' ),
					'type'    => 'color',
					'default' => '#00aff0',
					'desc'    => array(
						__( 'Change the Skype icon color.', 'woo-cart-share' ),
						/* translators: %s: Hex color code of the popup background color. */
						sprintf( __( 'Default %s', 'woo-cart-share' ), '<code>#00aff0</code>' ),
					),
					'classes' => 'wcss-color-selector',
				),
				'wcss_messenger_icon_color_code'  => array(
					'id'      => 'wcss_messenger_icon_color_code',
					'title'   => __( 'Messenger Icon Color', 'woo-cart-share' ),
					'type'    => 'color',
					'default' => '#0084ff',
					'desc'    => array(
						__( 'Change the Messenger icon color.', 'woo-cart-share' ),
						/* translators: %s: Hex color code of the popup background color. */
						sprintf( __( 'Default %s', 'woo-cart-share' ), '<code>#0084ff</code>' ),
					),
					'classes' => 'wcss-color-selector',
				),
				'wcss_print_cart_icon_color_code' => array(
					'id'      => 'wcss_print_cart_icon_color_code',
					'title'   => __( 'Print Cart Icon Color', 'woo-cart-share' ),
					'type'    => 'color',
					'default' => '#dd4b39',
					'desc'    => array(
						__( 'Change the print cart icon color.', 'woo-cart-share' ),
						/* translators: %s: Hex color code of the popup background color. */
						sprintf( __( 'Default %s', 'woo-cart-share' ), '<code>#dd4b39</code>' ),
					),
					'classes' => 'wcss-color-selector',
				),
				'wcss_save_cart_icon_color_code'  => array(
					'id'      => 'wcss_save_cart_icon_color_code',
					'title'   => __( 'Save Cart Icon Color', 'woo-cart-share' ),
					'type'    => 'color',
					'default' => '#00b489',
					'desc'    => array(
						__( 'Change the save cart icon color.', 'woo-cart-share' ),
						/* translators: %s: Hex color code of the popup background color. */
						sprintf( __( 'Default %s', 'woo-cart-share' ), '<code>#00b489</code>' ),
					),
					'classes' => 'wcss-color-selector',
				),
			),
		);

		// Basic Settings.
		$settings['wcss_basic_settings'] = array(
			'id'     => 'wcss_basic_settings',
			'title'  => __( 'Basic Settings', 'woo-cart-share' ),
			'fields' => array(
				'wcss_trigger_button_location' => array(
					'id'      => 'wcss_trigger_button_location',
					'title'   => __( 'Button Location', 'woo-cart-share' ),
					'type'    => 'select',
					'default' => 'with_apply_coupon',
					'desc'    => __( 'Change save cart button location on cart page.', 'woo-cart-share' ),
					'options' => array(
						'off'                 => __( 'Off', 'woo-cart-share' ),
						'with_apply_coupon'   => __( 'With - Apply coupon', 'woo-cart-share' ),
						'before_checkout_btn' => __( 'Before - Proceed to checkout', 'woo-cart-share' ),
						'after_checkout_btn'  => __( 'After - Proceed to checkout', 'woo-cart-share' ),
						'before_cart_table'   => __( 'Before - Cart Table', 'woo-cart-share' ),
						'after_cart_table'    => __( 'After - Cart Table', 'woo-cart-share' ),
						'cart_collaterals'    => __( 'Cart Collaterals', 'woo-cart-share' ),
						'before_cart_totals'  => __( 'Before - Cart Totals', 'woo-cart-share' ),
					),
				),
				'wcss_trigger_buttons_status' => array(
					'id'      => 'wcss_trigger_buttons_status',
					'title'   => __( 'Buttons Status', 'woo-cart-share' ),
					'type'    => 'wcss_checkbox_group',
					'desc'    => __( 'You can enable/ disable buttons on cart page.', 'woo-cart-share' ),
					'options' => array(
						'share_cart' => array(
							'default' => 'yes',
							'desc'    => __( 'Share Cart Button', 'woo-cart-share' ),
						),
						'save_cart' => array(
							'default' => 'no',
							'desc'    => __( 'Save Cart Button', 'woo-cart-share' ),
						),
						'email_cart' => array(
							'default' => 'no',
							'desc'    => __( 'Email Cart Button', 'woo-cart-share' ),
						),
						'print_cart' => array(
							'default' => 'no',
							'desc'    => __( 'Print Cart Button', 'woo-cart-share' ),
						),
					),
					'callback' => array( $this, 'field_checkbox_group' ),
					'sanitize' => array( $this, 'sanitize_checkbox_group' ),
				),
				'wcss_user_can_save_cart' => array(
					'id'      => 'wcss_user_can_save_cart',
					'type'    => 'checkbox',
					'title'   => __( 'User Can Save Cart?', 'woo-cart-share' ),
					'label'   => __( 'Enable this option if you want users can save cart.', 'woo-cart-share' ),
					'default' => 'yes',
				),
				'wcss_user_can_print_cart'                => array(
					'id'      => 'wcss_user_can_print_cart',
					'type'    => 'checkbox',
					'title'   => __( 'User Can Print Cart?', 'woo-cart-share' ),
					'label'   => __( 'Enable this option if you want users can print cart', 'woo-cart-share' ),
					'default' => 'yes',
				),
				'wcss_share_media'                        => array(
					'id'      => 'wcss_share_media',
					'title'   => __( 'Select Social Media', 'woo-cart-share' ),
					'type'    => 'wcss_checkbox_group',
					'desc'    => __( 'You can enable or disable share media channels.', 'woo-cart-share' ),
					'options' => array(
						'whatsapp'  => array(
							'default' => 'yes',
							'desc'    => __( 'Whatsapp', 'woo-cart-share' ),
						),
						'email'     => array(
							'default' => 'yes',
							'desc'    => __( 'Email', 'woo-cart-share' ),
						),
						'copy_link' => array(
							'default' => 'yes',
							'desc'    => __( 'Copy Link', 'woo-cart-share' ),
						),
						'facebook'  => array(
							'default' => 'yes',
							'desc'    => __( 'Facebook', 'woo-cart-share' ),
						),
						'twitter'   => array(
							'default' => 'yes',
							'desc'    => __( 'Twitter', 'woo-cart-share' ),
						),
						'skype'     => array(
							'default' => 'yes',
							'desc'    => __( 'Skype', 'woo-cart-share' ),
						),
						'messenger' => array(
							'default' => 'yes',
							'desc'    => __( 'Messenger (share integration required)', 'woo-cart-share' ),
						),
					),
					'callback' => array( $this, 'field_checkbox_group' ),
					'sanitize' => array( $this, 'sanitize_checkbox_group' ),
				),
				'wcss_display_by_role_status'             => array(
					'id'      => 'wcss_display_by_role_status',
					'type'    => 'checkbox',
					'title'   => __( 'Display By Roles', 'woo-cart-share' ),
					'label'   => __( 'Enable/ Disable', 'woo-cart-share' ),
					'desc'    => __( 'You can enable or disable share cart by the roles.', 'woo-cart-share' ),
					'default' => 'no',
				),
				'wcss_display_by_role'                    => array(
					'id'       => 'wcss_display_by_role',
					'type'     => 'select',
					'default'  => array(),
					'desc'     => __( 'Select roles', 'woo-cart-share' ),
					'classes'  => 'wcss-select2 regular-text',
					'multiple' => true,
					'options'  => array(
						'wp_roles' => 'all'
					),
				),
				'wcss_retrieved_cart_redirection_page_id' => array(
					'id'       => 'wcss_retrieved_cart_redirection_page_id',
					'title'    => __( 'Retrieved Cart Redirection', 'woo-cart-share' ),
					'type'     => 'select',
					'default'  => get_option( 'woocommerce_cart_page_id' ),
					'desc'     => array(
						__( 'Select the page where user redirect after retrieve a shared cart.', 'woo-cart-share' ),
						sprintf( __( 'Default: %s', 'woo-cart-share' ), '<code>' . get_the_title( get_option( 'woocommerce_cart_page_id' ) ) . '</code>' ),
					),
					'classes'  => 'wcss-select2 regular-text',
					'options'  => array(
						'wp_query' => array(
							'post_type'      => 'page',
							'posts_per_page' => -1,
							'orderby'        => 'title',
							'order'          => 'ASC',
						)
					),
				),
				'wcss_social_share_message'               => array(
					'id'      => 'wcss_social_share_message',
					'title'   => __( 'Social Share Message', 'woo-cart-share' ),
					'type'    => 'textarea',
					'default' => 'Hey, Check Out This {link}',
					'desc'    => array(
						__( 'This message will send with shared link.', 'woo-cart-share' ),
						sprintf( __( 'Use %s for the share cart link.', 'woo-cart-share' ), '<code>{link}</code>' )
					),
					'rows'    => 8,
				),
				'wcss_custom_css'                         => array(
					'id'      => 'wcss_custom_css',
					'title'   => __( 'Custom CSS', 'woo-cart-share' ),
					'type'    => 'textarea',
					'default' => '',
					'desc'    => __( 'Enter your custom CSS.', 'woo-cart-share' ),
					'rows'    => 8,
					'style'   => array(
						'background' => '#263238',
						'color'      => '#ffffff',
						'max-width'  => '100%',
						'width'      => '500px',
					),
				),
				'wscc_developemnt_settings_link'          => array(
					'id'       => 'wscc_developemnt_settings_link',
					'title'    => __( 'Developer Settings', 'woo-cart-share' ),
					'type'     => 'wcss_link',
					'link'     => admin_url( 'admin.php?page=woocommerce-cart-share&tab=developer_settings' ),
					'desc'     => __( 'Please do not make changes here without our permission.', 'woo-cart-share' ),
					'value'    => __( 'Goto developer settings', 'woo-cart-share' ),
					'callback' => array( $this, 'field_link' ),
				)
			),
		);

		// Advanced settings.
		$settings['wcss_advanced_settings'] = array(
			'id'     => 'wcss_advanced_settings',
			'title'  => __( 'Advanced Settings', 'woo-cart-share' ),
			'fields' => array(
				'wcss_automatically_delete_cart_options'           => array(
					'id'      => 'wcss_automatically_delete_cart_options',
					'title'   => __( 'Automatically Delete Cart Options', 'woo-cart-share' ),
					'type'    => 'wcss_checkbox_group',
					'options' => array(
						'shared_cart_after_retrieved' => array(
							'default' => 'no',
							'desc'    => __( 'Delete shared cart after retrieved?', 'woo-cart-share' ),
						),
						'saved_cart_after_retrieved' => array(
							'default' => 'no',
							'desc'    => __( 'Delete saved cart after retrieved?', 'woo-cart-share' ),
						),
						'shared_and_saved_cart_after_retrieved' => array(
							'default' => 'no',
							'desc'    => __( 'Delete saved and shared cart after retrieved?', 'woo-cart-share' ),
						),
					),
					'callback' => array( $this, 'field_checkbox_group' ),
					'sanitize' => array( $this, 'sanitize_checkbox_group' ),
				),
				'wcss_automatically_delete_old_shared_cart_period' => array(
					'id'      => 'wcss_automatically_delete_old_shared_cart_period',
					'title'   => __( 'Automatically Delete Shared Cart After', 'woo-cart-share' ),
					'type'    => 'select',
					'desc'    => array(
						__( 'Select the period of time after which shared cart will be deleted automatically.', 'woo-cart-share' ),
						__( 'The process will delete 1000 shared carts within a 24-hour period.', 'woo-cart-share' ),
						wp_sprintf( 'Next run at %s', '<code>' . gmdate( 'M j, Y g:i a', get_transient( 'wcss_delete_old_shared_cart_periodically' ) ) . '</code>' ),
					),
					'default' => 'none',
					'options' => array(
						'none' => __( 'None', 'woo-cart-share' ),
						'1'    => __( '1 Day', 'woo-cart-share' ),
						'2'    => __( '2 Days', 'woo-cart-share' ),
						'3'    => __( '3 Days', 'woo-cart-share' ),
						'10'   => __( '10 Days', 'woo-cart-share' ),
						'15'   => __( '15 Days', 'woo-cart-share' ),
						'30'   => __( '1 Month', 'woo-cart-share' ),
						'60'   => __( '2 Months', 'woo-cart-share' ),
						'90'   => __( '3 Months', 'woo-cart-share' ),
						'180'  => __( '6 Months', 'woo-cart-share' ),
						'365'  => __( '1 Year', 'woo-cart-share' ),
						'720'  => __( '2 Years', 'woo-cart-share' ),
						'1826' => __( '5 Years', 'woo-cart-share' ),
					),
				),
			),
		);

		// Popup Text Settings.
		$settings['wcss_popup_text_settings'] = array(
			'id'     => 'wcss_popup_text_settings',
			'title'  => __( 'Popup Text Settings', 'woo-cart-share' ),
			'fields' => array(
				'wcss_share_cart_button_text'          => array(
					'id'      => 'wcss_share_cart_button_text',
					'type'    => 'text',
					'title'   => __( 'Share Cart Button Text', 'woo-cart-share' ),
					'desc'    => __( 'Change share cart button text.', 'woo-cart-share' ),
					'default' => 'Share cart',
				),
				'wcss_share_cart_title'                => array(
					'id'      => 'wcss_share_cart_title',
					'type'    => 'text',
					'title'   => __( 'Share Cart Title', 'woo-cart-share' ),
					'desc'    => __( 'Change share cart title message.', 'woo-cart-share' ),
					'default' => 'SHARE YOUR CART',
				),
				'wcss_save_cart_button_text'           => array(
					'id'      => 'wcss_save_cart_button_text',
					'type'    => 'text',
					'title'   => __( 'Save Cart Button Text', 'woo-cart-share' ),
					'desc'    => __( 'Change save cart button text.', 'woo-cart-share' ),
					'default' => 'Save Cart',
				),
				'wcss_email_cart_button_text'          => array(
					'id'      => 'wcss_email_cart_button_text',
					'type'    => 'text',
					'title'   => __( 'Email Cart Button Text', 'woo-cart-share' ),
					'desc'    => __( 'Change email cart button text.', 'woo-cart-share' ),
					'default' => 'Email Cart',
				),
				'wcss_print_cart_button_text'          => array(
					'id'      => 'wcss_print_cart_button_text',
					'type'    => 'text',
					'title'   => __( 'Print Cart Button Text', 'woo-cart-share' ),
					'desc'    => __( 'Change print cart button text.', 'woo-cart-share' ),
					'default' => 'Print Cart',
				),
				'wcss_save_cart_input_placeholder'     => array(
					'id'      => 'wcss_save_cart_input_placeholder',
					'type'    => 'text',
					'title'   => __( 'Save Cart Input Placeholder', 'woo-cart-share' ),
					'desc'    => __( 'Change save cart input box placeholder.', 'woo-cart-share' ),
					'default' => 'Enter your cart name',
				),
				'wcss_save_cart_message'               => array(
					'id'      => 'wcss_save_cart_message',
					'type'    => 'textarea',
					'title'   => __( 'Save Cart Message', 'woo-cart-share' ),
					'desc'    => __( 'Change save cart message.', 'woo-cart-share' ),
					'rows'    => 8,
					'default' => 'You can restore saved cart and share directly anytime from your my-account page',
				),
				'wcss_save_cart_not_logged_in_message' => array(
					'id'      => 'wcss_save_cart_not_logged_in_message',
					'type'    => 'wp_editor',
					'title'   => __( 'Save Cart Not Logged in Message', 'woo-cart-share' ),
					'desc'    => __( 'Change save cart message if user not logged in.', 'woo-cart-share' ),
					'default' => '<p>You need to log in before saving the cart.</p><p><a href="' . get_permalink( get_option( 'woocommerce_myaccount_page_id' ) ) . '" class="button">Login Now</a></p>',
				),
				'wcss_empty_cart_message'              => array(
					'id'      => 'wcss_empty_cart_message',
					'type'    => 'wp_editor',
					'title'   => __( 'Empty Cart Message', 'woo-cart-share' ),
					'desc'    => __( 'Enter message for empty cart message.', 'woo-cart-share' ),
					'default' => '<p>Your cart is empty, create a new one.</p><p><a href="' . get_permalink( wc_get_page_id( 'shop' ) ) . '">Shop Now</a></p>',
				),
				'wcss_cart_retrieved_message'          => array(
					'id'      => 'wcss_cart_retrieved_message',
					'type'    => 'textarea',
					'title'   => __( 'Empty Retrieved Message', 'woo-cart-share' ),
					'desc'    => __( 'Enter message for successfully cart retrieved.', 'woo-cart-share' ),
					'rows'    => 8,
					'default' => 'Cart retrieved successfully',
				),
				'wcss_cart_not_found_message'          => array(
					'id'      => 'wcss_cart_not_found_message',
					'type'    => 'textarea',
					'title'   => __( 'Cart Not Found Message', 'woo-cart-share' ),
					'desc'    => __( 'Enter message for cart not found.', 'woo-cart-share' ),
					'rows'    => 8,
					'default' => 'The cart you\'re looking for no longer exists.',
				),
				'wcss_share_cart_email_to_label'       => array(
					'id'      => 'wcss_share_cart_email_to_label',
					'type'    => 'text',
					'title'   => __( 'Label For Email To', 'woo-cart-share' ),
					'desc'    => __( 'Enter the label for email to.', 'woo-cart-share' ),
					'default' => 'Email To',
				),
				'wcss_share_cart_email_subject_label'  => array(
					'id'      => 'wcss_share_cart_email_subject_label',
					'type'    => 'text',
					'title'   => __( 'Label For Subject', 'woo-cart-share' ),
					'desc'    => __( 'Enter the label for email subject.', 'woo-cart-share' ),
					'default' => 'Subject',
				),
				'wcss_share_cart_email_message_label'  => array(
					'id'      => 'wcss_share_cart_email_message_label',
					'type'    => 'text',
					'title'   => __( 'Label For Message', 'woo-cart-share' ),
					'desc'    => __( 'Enter the label for email message.', 'woo-cart-share' ),
					'default' => 'Message',
				),
				'wcss_share_cart_email_button_text'    => array(
					'id'      => 'wcss_share_cart_email_button_text',
					'type'    => 'text',
					'title'   => __( 'Send Cart Button Text', 'woo-cart-share' ),
					'desc'    => __( 'Enter the label for share cart button under the email form.', 'woo-cart-share' ),
					'default' => 'Send Cart',
				),
			),
		);

		// My Account Settings.
		$settings['wcss_my_account_settings'] = array(
			'id'     => 'wcss_my_account_settings',
			'title'  => __( 'My Account', 'woo-cart-share' ),
			'fields' => array(
				'wcss_my_account_tab_name'                           => array(
					'id'       => 'wcss_my_account_tab_name',
					'type'     => 'text',
					'title'    => __( 'Tab Name', 'woo-cart-share' ),
					'desc'     => __( 'You can change the tab name from here.', 'woo-cart-share' ),
					'default'  => 'Saved Cart',
					'required' => true,
				),
				'wcss_my_account_tab_slug'                           => array(
					'id'         => 'wcss_my_account_tab_slug',
					'type'       => 'text',
					'title'      => __( 'Slug', 'woo-cart-share' ),
					'desc'       => sprintf( __( 'Default %s', 'woo-cart-share' ), '<code>saved-cart</code>' ),
					'desc'       => __( 'You can change the slug ( URL parameter ) from here.', 'woo-cart-share' ),
					'default'    => 'saved-cart',
					'attributes' => array(
						'required' => 'required'
					),
				),
				'wcss_my_account_restore_button_lable'               => array(
					'id'      => 'wcss_my_account_restore_button_lable',
					'type'    => 'text',
					'title'   => __( 'Restore Cart Button Label', 'woo-cart-share' ),
					'default' => 'Restore',
				),
				'wcss_my_account_share_button_lable'                 => array(
					'id'      => 'wcss_my_account_share_button_lable',
					'type'    => 'text',
					'title'   => __( 'Share Cart Button Label', 'woo-cart-share' ),
					'default' => 'Share',
				),
				'wcss_my_account_delete_button_lable'                => array(
					'id'      => 'wcss_my_account_delete_button_lable',
					'type'    => 'text',
					'title'   => __( 'Delete Cart Button Label', 'woo-cart-share' ),
					'default' => 'Delete',
				),
				'wcss_my_account_empty_saved_cart_button_text'       => array(
					'id'       => 'wcss_my_account_empty_saved_cart_button_text',
					'type'     => 'text',
					'title'    => __( 'Empty Saved Cart Button', 'woo-cart-share' ),
					'desc'     => __( 'Enter button label for no saved cart.', 'woo-cart-share' ),
					'default'  => 'Go shop',
				),
				'wcss_my_account_empty_saved_cart_message'           => array(
					'id'       => 'wcss_my_account_empty_saved_cart_message',
					'type'     => 'textarea',
					'title'    => __( 'Empty Saved Cart Message', 'woo-cart-share' ),
					'desc'     => __( 'Enter message for no saved cart.', 'woo-cart-share' ),
					'default'  => 'No saved cart yet.',
					'row'      => 8,
				),
				'wcss_my_account_saved_cart_search_placeholder_text' => array(
					'id'       => 'wcss_my_account_saved_cart_search_placeholder_text',
					'type'     => 'text',
					'title'    => __( 'Saved Cart Search Placeholder', 'woo-cart-share' ),
					'desc'     => __( 'Enter the text for saved cart search input placeholder.', 'woo-cart-share' ),
					'default'  => 'Search your saved cart',
				),
			),
		);

		// Email Settings.
		$settings['wcss_email_settings'] = array(
			'id'     => 'wcss_email_settings',
			'title'  => __( 'Email Settings', 'woo-cart-share' ),
			'fields' => array(
				'wcss_email_brand_logo_url'            => array(
					'id'         => 'wcss_email_brand_logo_url',
					'type'       => 'file',
					'title'      => __( 'Brand Logo', 'woo-cart-share' ),
					'desc'       => __( 'Upload your brand logo.', 'woo-cart-share' ),
					'default'    => WCSS_PLUGIN_URL . 'assets/images/email/email-logo.png',
					'style'      => array(
						'width' => 'width:240px',
					),
				),
				'wcss_email_brand_name'                => array(
					'id'       => 'wcss_email_brand_name',
					'type'     => 'text',
					'title'    => __( 'Brand Name', 'woo-cart-share' ),
					'desc'     => __( 'Enter your brand name.', 'woo-cart-share' ),
					'default'  => get_bloginfo( 'name' ),
				),
				'wcss_email_background_color'          => array(
					'id'       => 'wcss_email_background_color',
					'type'     => 'color',
					'title'    => __( 'Email Background Color', 'woo-cart-share' ),
					'desc'     => __( 'Change the email background color.', 'woo-cart-share' ),
					'classes'  => 'wcss-color-selector',
					'default'  => '#eceff1',
				),
				'wcss_email_header_background_color'   => array(
					'id'       => 'wcss_email_header_background_color',
					'type'     => 'color',
					'title'    => __( 'Header Background Color', 'woo-cart-share' ),
					'desc'     => __( 'Change the email header and footer background color.', 'woo-cart-share' ),
					'classes'  => 'wcss-color-selector',
					'default'  => '#333333',
				),
				'wcss_email_header_text_color'         => array(
					'id'       => 'wcss_email_header_text_color',
					'type'     => 'color',
					'title'    => __( 'Header Text Color', 'woo-cart-share' ),
					'desc'     => __( 'Change the email header and footer text color.', 'woo-cart-share' ),
					'classes'  => 'wcss-color-selector',
					'default'  => '#ffffff',
				),
				'wcss_email_button_background_color'   => array(
					'id'       => 'wcss_email_button_background_color',
					'type'     => 'color',
					'title'    => __( 'Button Background Color', 'woo-cart-share' ),
					'desc'     => __( 'Change the email button background color.', 'woo-cart-share' ),
					'classes'  => 'wcss-color-selector',
					'default'  => '#7F54B3',
				),
				'wcss_email_button_text_color'         => array(
					'id'       => 'wcss_email_button_text_color',
					'type'     => 'color',
					'title'    => __( 'Button Text Color', 'woo-cart-share' ),
					'desc'     => __( 'Change the email button text color.', 'woo-cart-share' ),
					'classes'  => 'wcss-color-selector',
					'default'  => '#ffffff',
				),
				'wcss_email_body_background_color'     => array(
					'id'       => 'wcss_email_body_background_color',
					'type'     => 'color',
					'title'    => __( 'Body Color', 'woo-cart-share' ),
					'desc'     => __( 'Change the email body background color.', 'woo-cart-share' ),
					'classes'  => 'wcss-color-selector',
					'default'  => '#ffffff',
				),
				'wcss_email_retrieve_cart_button_text' => array(
					'id'       => 'wcss_email_retrieve_cart_button_text',
					'type'     => 'text',
					'title'    => __( 'Button Text', 'woo-cart-share' ),
					'desc'     => __( 'You can change the button text here.', 'woo-cart-share' ),
					'default'  => 'RETRIEVE CART',
				),
				'wcss_email_description'               => array(
					'id'      => 'wcss_email_description',
					'type'    => 'wp_editor',
					'title'   => __( 'Email Description', 'woo-cart-share' ),
					'desc'    => __( 'Add the email description here.', 'woo-cart-share' ),
					'default' => '<p style="text-align: center;">Have a look at the shopping cart 😉</p>',
				),
				'wcss_email_contact_media'             => array(
					'id'     => 'wcss_email_contact_media',
					'type'   => 'wcss_email_contact_media',
					'title'  => __( 'Follow Us', 'woo-cart-share' ),
					'fields' => array(
						'facebook'  => array(
							'id'      => 'wcss_email_contact_media[facebook]',
							'type'    => 'text',
							'title'   => __( 'Facebook', 'woo-cart-share' ),
							'desc'    => __( 'Leave blank for disable.', 'woo-cart-share' ),
							'default' => '#',
						),
						'instagram' => array(
							'id'      => 'wcss_email_contact_media[instagram]',
							'type'    => 'text',
							'title'   => __( 'Instagram', 'woo-cart-share' ),
							'desc'    => __( 'Leave blank for disable.', 'woo-cart-share' ),
							'default' => '#',
						),
						'twitter'   => array(
							'id'      => 'wcss_email_contact_media[twitter]',
							'type'    => 'text',
							'title'   => __( 'Twitter', 'woo-cart-share' ),
							'desc'    => __( 'Leave blank for disable.', 'woo-cart-share' ),
							'default' => '#',
 						),
						'whatsapp'  => array(
							 'id'      => 'wcss_email_contact_media[whatsapp]',
							 'type'    => 'text',
							 'title'   => __( 'WhatsApp', 'woo-cart-share' ),
							 'desc'    => __( 'Enter mobile phone number with the international country code, without + character. Example:  911234567890 for (+91) 1234567890', 'woo-cart-share' ),
							 'default' => '911234567889',
 						),
					),
					'callback' => array( $this, 'field_email_contact_media' ),
					'sanitize' => array( $this, 'sanitize_email_contact_media' ),
				),
				'wcss_email_from_name'                 => array(
					'id'       => 'wcss_email_from_name',
					'type'     => 'text',
					'title'    => __( 'Email From Name', 'woo-cart-share' ),
					'desc'     => array(
						__( 'Enter the email come from name.', 'woo-cart-share' ),
						sprintf( __( 'For best practice use %s', 'woo-cart-share' ), '<code>' . get_bloginfo( 'name' ) . '</code>' ),
					),
					'default'  => get_bloginfo( 'name' ),
				),
				'wcss_email_from_email'                => array(
					'id'       => 'wcss_email_from_email',
					'type'     => 'email',
					'title'    => __( 'Email From', 'woo-cart-share' ),
					'desc'     => array(
						__( 'Enter an email of your store.', 'woo-cart-share' ),
						sprintf( __( 'For best practice use %s', 'woo-cart-share' ), '<code>' . get_bloginfo( 'admin_email' ) . '</code>' ),
					),
					'default'  => get_bloginfo( 'admin_email' ),
				),
				'wcss_email_remove_retrieve_cart_link' => array(
					'id'       => 'wcss_email_remove_retrieve_cart_link',
					'type'     => 'checkbox',
					'title'    => __( 'Remove Retrieve Cart Link', 'woo-cart-share' ),
					'label'    => __( 'Enable/ Disable', 'woo-cart-share' ),
					'desc'     => __( 'Enable this option if you want to remove the retrieve cart link.', 'woo-cart-share' ),
					'default'  => 'no',
				),
				'wcss_email_remove_product_link'       => array(
					'id'       => 'wcss_email_remove_product_link',
					'type'     => 'checkbox',
					'title'    => __( 'Remove Product Link', 'woo-cart-share' ),
					'label'    => __( 'Enable/ Disable', 'woo-cart-share' ),
					'desc'     => __( 'Enable this option if you want to remove the product link.', 'woo-cart-share' ),
					'default'  => 'no',
				),
				'wcss_preview_email_cart'              => array(
					'id'       => 'wcss_preview_email_cart',
					'type'     => 'wcss_link',
					'title'    => __( 'Preview Email', 'woo-cart-share' ),
					'value'    => __( 'Preview Email', 'woo-cart-share' ),
					'link'     => admin_url( 'admin.php?page=woocommerce-cart-share&tab=preview_email_cart' ),
					'classes'  => 'button',
					'callback' => array( $this, 'field_link' ),
					'register' => false,
				),
			),
		);

		// Print cart Settings.
		$settings['wcss_print_cart_settings'] = array(
			'id'     => 'wcss_print_cart_settings',
			'title'  => __( 'Print Cart Settings', 'woo-cart-share' ),
			'fields' => array(
				'wcss_print_cart_brand_logo_url'              => array(
					'id'         => 'wcss_print_cart_brand_logo_url',
					'type'       => 'file',
					'title'      => __( 'Brand Logo', 'woo-cart-share' ),
					'desc'       => __( 'Upload your brand logo.', 'woo-cart-share' ),
					'default'    => WCSS_PLUGIN_URL . 'assets/images/email/email-logo.png',
					'style'      => array(
						'width' => 'width:240px',
					),
				),
				'wcss_print_cart_header_background_color'     => array(
					'id'       => 'wcss_print_cart_header_background_color',
					'type'     => 'color',
					'title'    => __( 'Header Background Color', 'woo-cart-share' ),
					'desc'     => __( 'Change the print cart header background color.', 'woo-cart-share' ),
					'classes'  => 'wcss-color-selector',
					'default'  => '#eeeeee',
				),
				'wcss_print_cart_button_background_color'     => array(
					'id'       => 'wcss_print_cart_button_background_color',
					'type'     => 'color',
					'title'    => __( 'Button Background Color', 'woo-cart-share' ),
					'desc'     => __( 'Change the print cart button background color.', 'woo-cart-share' ),
					'classes'  => 'wcss-color-selector',
					'default'  => '#7F54B3',
				),
				'wcss_print_cart_button_text_color'           => array(
					'id'       => 'wcss_print_cart_button_text_color',
					'type'     => 'color',
					'title'    => __( 'Button Text Color', 'woo-cart-share' ),
					'desc'     => __( 'Change the print cart button text color.', 'woo-cart-share' ),
					'classes'  => 'wcss-color-selector',
					'default'  => '#ffffff',
				),
				'wcss_print_cart_retrieve_cart_button_text'   => array(
					'id'       => 'wcss_print_cart_retrieve_cart_button_text',
					'type'     => 'text',
					'title'    => __( 'Button Text', 'woo-cart-share' ),
					'desc'     => __( 'You can change the button text here.', 'woo-cart-share' ),
					'default'  => 'RETRIEVE CART',
				),
				'wcss_print_cart_file_name'                   => array(
					'id'       => 'wcss_print_cart_file_name',
					'type'     => 'text',
					'title'    => __( 'Print Cart File Name', 'woo-cart-share' ),
					'desc'    => array(
						__( 'You can change the print cart file name.', 'woo-cart-share' ),
						/* translators: %s: Print cart file name. */
						sprintf( __( 'Default %s', 'woo-cart-share' ), '<code>print-cart</code>' ),
					),
					'default'  => 'print-cart',
				),
				'wcss_print_cart_retrieve_cart_button_status' => array(
					'id'       => 'wcss_print_cart_retrieve_cart_button_status',
					'type'     => 'checkbox',
					'title'    => __( 'Retrieve Cart Button', 'woo-cart-share' ),
					'label'    => __( 'Enable/ Disable', 'woo-cart-share' ),
					'desc'     => __( 'Disable this option if you want to remove retrieve cart button.', 'woo-cart-share' ),
					'default'  => 'yes',
				),
				'wcss_print_cart_retrieve_cart_link_status'   => array(
					'id'       => 'wcss_print_cart_retrieve_cart_link_status',
					'type'     => 'checkbox',
					'title'    => __( 'Retrieve Cart Link', 'woo-cart-share' ),
					'label'    => __( 'Enable/ Disable', 'woo-cart-share' ),
					'desc'     => __( 'Disable this option if you want to remove retrieve cart link.', 'woo-cart-share' ),
					'default'  => 'yes',
				),
				'wcss_print_cart_remove_product_link'         => array(
					'id'       => 'wcss_print_cart_remove_product_link',
					'type'     => 'checkbox',
					'title'    => __( 'Remove Product Link', 'woo-cart-share' ),
					'label'    => __( 'Enable/ Disable', 'woo-cart-share' ),
					'desc'     => __( 'Enable this option if you want to remove the product link.', 'woo-cart-share' ),
					'default'  => 'no',
				),
				'wcss_print_cart_website_style_status'        => array(
					'id'       => 'wcss_print_cart_website_style_status',
					'type'     => 'checkbox',
					'title'    => __( 'Website Style', 'woo-cart-share' ),
					'label'    => __( 'Enable/ Disable', 'woo-cart-share' ),
					'desc'     => __( 'Enable this option if you want to disable plugin print style and enable website style.', 'woo-cart-share' ),
					'default'  => 'no',
				),
			),
		);

		// Developer Settings.
		$settings['wcss_developer_settings'] = array(
			'id'     => 'wcss_developer_settings',
			'title'  => __( 'Developer Settings', 'woo-cart-share' ),
			'fields' => array(
				'wcss_base_slug'                     => array(
					'id'       => 'wcss_base_slug',
					'type'     => 'text',
					'title'    => __( 'Share Cart Base URL', 'woo-cart-share' ),
					'required' => true,
					'desc'     => array(
						__( 'You can change the share cart base URL.', 'woo-cart-share' ),
						sprintf( __( 'Default: %s', 'woo-cart-share' ), '<code>cart-share</code>' ),
					),
					'default'  => 'cart-share',
				),
				'wcss_fix_404_issue_button'          => array(
					'id'       => 'wcss_fix_404_issue_button',
					'type'     => 'wcss_link',
					'title'    => __( 'Fix 404 Issue', 'woo-cart-share' ),
					'desc'     => __( 'Fix 404 redirection issue while retrieving cart.', 'woo-cart-share' ),
					'value'    => __( 'Fix Now', 'woo-cart-share' ),
					'link'     => wp_nonce_url( '?wcss_flush_rewrite_rules=1' ),
					'classes'  => 'button',
					'callback' => array( $this, 'field_link' ),
					'register' => false,
				),
				'wcss_reset_settings'                => array(
					'id'         => 'wcss_reset_settings',
					'type'       => 'wcss_link',
					'title'      => __( 'Reset Settings', 'woo-cart-share' ),
					'desc'       => __( 'Reset all settings to default.', 'woo-cart-share' ),
					'value'      => __( 'Reset', 'woo-cart-share' ),
					'link'       => wp_nonce_url( '?wcss_reset_settings=1' ),
					'classes'  => 'button',
					'attributes' => array(
						'onClick' => 'return confirm( "' . __( 'Are you sure?', 'woo-cart-share' ) . '" )',
					),
					'callback' => array( $this, 'field_link' ),
					'register' => false,
				),
				'wcss_delete_saved_carts'            => array(
					'id'         => 'wcss_delete_saved_carts',
					'type'       => 'wcss_link',
					'title'      => __( 'Delete Saved Cart', 'woo-cart-share' ),
					'desc'       => __( 'Delete all saved cart by users and admin but not shared cart.', 'woo-cart-share' ),
					'value'      => __( 'Delete', 'woo-cart-share' ),
					'link'       => wp_nonce_url( admin_url( '?wcss_admin_action=delete_saved_carts' ), 'wcss_delete_saved_carts', 'wcss_delete_saved_carts' ),
					'classes'  => 'button',
					'attributes' => array(
						'onClick' => 'return confirm( "' . __( 'Are you sure?', 'woo-cart-share' ) . '" )',
					),
					'callback' => array( $this, 'field_link' ),
					'register' => false,
				),
				'wcss_delete_shared_and_saved_carts' => array(
					'id'         => 'wcss_delete_shared_and_saved_carts',
					'type'       => 'wcss_link',
					'title'      => __( 'Delete Saved & Shared Cart', 'woo-cart-share' ),
					'desc'       => __( 'Delete all saved cart shared cart by users and admin.', 'woo-cart-share' ),
					'value'      => __( 'Delete', 'woo-cart-share' ),
					'link'       => wp_nonce_url( '?wcss_admin_action=delete_shared_and_saved_carts', 'wcss_delete_shared_and_saved_carts', 'wcss_delete_shared_and_saved_carts' ),
					'classes'  => 'button',
					'attributes' => array(
						'onClick' => 'return confirm( "' . __( 'Are you sure?', 'woo-cart-share' ) . '" )',
					),
					'callback' => array( $this, 'field_link' ),
					'register' => false,
				),
				'wcss_delete_all'                    => array(
					'id'       => 'wcss_delete_all',
					'type'     => 'checkbox',
					'label'    => __( 'Enable/ Disable', 'woo-cart-share' ),
					'title'    => __( 'Delete Plugin Setting', 'woo-cart-share' ),
					'desc'     => __( 'If you want to delete plugin settings stored in database then enable this option and then click on the save changes button. Now delete the plugin from your plugins page.', 'woo-cart-share' ),
					'default'  => 'no',
				),
			),
		);

		return $settings;
	}

	/**
	 * Add plugin options.
	 *
	 * @since 2.0.0
	 *
	 * @param string $field_id Field ID or field name.
	 * @param array  $field    Field data.
	 * @return void
	 */
	public function add_plugin_options( $field_id, $field ) {
		if ( isset( $field['type'] ) && 'wcss_checkbox_group' === $field['type'] ) {
			$defalt_options = isset( $field['options'] ) ? wp_unslash( $field['options'] ) : array();
			$db_options     = get_option( $field_id );

			if ( ! $db_options ) {
				$db_options = array();
			}

			if ( $defalt_options ) {
				foreach ( $defalt_options as $option_key => $option ) {
					if ( isset( $db_options[ $option_key ] ) ) {
						continue;
					}
					if ( ! isset( $option['default'] ) ) {
						continue;
					}

					$db_options[ $option_key ] = sanitize_text_field( $option['default'] );
				}
			}

			update_option( $field_id, $db_options );
		}

		if ( isset( $field['type'] ) && 'wcss_email_contact_media' === $field['type'] ) {
			$defalt_options = isset( $field['fields'] ) ? wp_unslash( $field['fields'] ) : array();
			$db_options     = get_option( $field_id );

			if ( ! $db_options ) {
				$db_options = array();
			}

			if ( $defalt_options ) {
				foreach ( $defalt_options as $option_key => $option ) {
					if ( isset( $db_options[ $option_key ] ) ) {
						continue;
					}
					if ( ! isset( $option['default'] ) ) {
						continue;
					}

					$db_options[ $option_key ] = sanitize_text_field( $option['default'] );
				}
			}

			update_option( $field_id, $db_options );
		}
	}

	/**
	 * Render checkbox group fields.
	 *
	 * @since 2.0.0
	 *
	 * @param  array $args Field arguments.
	 * @return void
	 */
	public function field_checkbox_group( $args ) {
		$name        = isset( $args['name'] ) ? $args['name'] : $args['id'];
		$classes     = isset( $args['classes'] ) ? $args['classes'] : '';
		$custom_attr = self::field_attributes( $args );
		$values      = self::get_option( $args );

		echo '<fieldset>';

		foreach ( $args['options'] as $option_key => $option ) {
			$checked = checked( 'yes', isset( $values[ $option_key ] ) ? $values[ $option_key ] : '0', false );

			printf(
				'<label>
					<input type="hidden" name="%1$s[temp][%2$s]" value="nothing"/>
					<input type="checkbox" id="%1$s[%2$s]" class="%3$s" name="%1$s[%2$s]" value="yes" %4$s %5$s /> <span>%6$s</span>
				</label>
				<br />',
				esc_attr( $name ),
				esc_attr( $option_key ),
				esc_attr( $classes ),
				$custom_attr, // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				$checked, // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
				wp_kses_post( $option['desc'] )
			);
		}

		echo self::field_description( $args );
		echo '</fieldset>';
	}

	/**
	 * Render link fields.
	 *
	 * @since 2.0.0
	 *
	 * @param  array $args Field arguments.
	 * @return void
	 */
	public function field_link( $args ) {
		$classes     = isset( $args['classes'] ) ? $args['classes'] : '';
		$custom_attr = self::field_attributes( $args );

		echo sprintf(
			'<a href="%1$s" class="%2$s" %4$s>%3$s</a>',
			esc_url( $args['link'] ),
			esc_attr( $classes ),
			esc_html( $args['value'] ),
			$custom_attr // phpcs:ignore WordPress.Security.EscapeOutput.OutputNotEscaped
		);

		echo self::field_description( $args );
	}

	/**
	 * Render email contact media fields.
	 *
	 * @since 2.0.0
	 *
	 * @param  array $args Field arguments.
	 * @return void
	 */
	public function field_email_contact_media( $args ) {
		if ( $args['fields'] ) {
			$email_contact_media = get_option( 'wcss_email_contact_media', array() );

			foreach ( $args['fields'] as $field_key => $field ) {
				echo '<div style="margin-bottom: 20px;">';
				echo '<strong>' . esc_html( $field['title'] ) . '</strong>';
				echo '<br />';

				$field['value'] = isset( $email_contact_media[ $field_key ] ) ? $email_contact_media[ $field_key ] : $field['default'];

				self::field_text( $field );

				echo '</div>';
			}
		}
	}

	/**
	 * Sanitize checkbox group fields.
	 *
	 * @since 2.0.0
	 *
	 * @param array $input Array of input values.
	 * @return array Filtered input.
	 */
	public function sanitize_checkbox_group( $input ) {
		$new_input = array();

		if ( is_array( $input ) ) {
			foreach ( $input['temp'] as $t_k => $t_v ) {
				$new_input[ $t_k ] = isset( $input[ $t_k ] ) ? 'yes' : 'no';
			}
		}

		return $new_input;
	}

	/**
	 * Sanitize email contact media fields.
	 *
	 * @since 2.0.0
	 *
	 * @param array $input Array of input values.
	 * @return array Filtered input.
	 */
	public function sanitize_email_contact_media( $input ) {
		$new_input = array();

		if ( is_array( $input ) ) {
			foreach ( $input as $t_k => $t_v ) {
				$new_input[ $t_k ] = isset( $input[ $t_k ] ) ? wp_kses_post( $input[ $t_k ] ) : '';
			}
		}

		return $new_input;
	}

	/**
	 * Sanitize share integration fields.
	 *
	 * @since 2.0.0
	 *
	 * @param array $input Array of input values.
	 * @return array Filtered input.
	 */
	public function sanitize_share_intergration( $input ) {
		$input['messenger']['app_id'] = sanitize_text_field( $input['messenger']['app_id'] );

		return $input;
	}

	/**
	 * Register legacy settings.
	 *
	 * @since 2.0.0
	 *
	 * @return void
	 */
	public function legacy_register_settings() {
		register_setting( 'wcss_share_integration_settings', 'wcss_share_integration', array( $this, 'sanitize_share_intergration' ) );
	}
}

return new WCSS_Settings();
