<?php

// Exit if accessed directly
defined( 'ABSPATH' ) || exit;

class WCSS_Shortcodes {

	public function __construct() {
		add_shortcode( 'wcss-share-cart-btn', array( $this, 'share_button_shortcode' ) );
		add_shortcode( 'wcss-save-cart-btn', array( $this, 'save_button_shortcode' ) );
		add_shortcode( 'wcss-email-cart-btn', array( $this, 'email_button_shortcode' ) );
		add_shortcode( 'wcss-display-saved-carts', array( $this, 'saved_carts_display' ) );
	}

	/**
	 * Share cart button shortcode.
	 *
	 * @param array $atts
	 * @return void
	 */
	public function share_button_shortcode( $atts ) {
		// If current user has no access to share the cart then shortcode display nothing.
		if ( wcss_currnet_role_has_access() !== true ) {
			return;
		}

		$a = shortcode_atts(
			array(
				'text'      => esc_html( get_option( 'wcss_share_cart_button_text' ) ),
				'bgColor'   => esc_html( get_option( 'wcss_button_background_color' ) ),
				'textColor' => esc_html( get_option( 'wcss_button_text_color' ) ),
			),
			$atts
		);

		$style  = "background-color: {$a['bgColor']};";
		$style .= "color: {$a['textColor']};";

		return sprintf(
			'<a href="javascript:void( wcss.open_share_media_popup() )" class="wcss-share-cart-btn-shortcode" style="%s">%s</a>',
			$style,
			esc_html( $a['text'] )
		);
	}

	/**
	 * Save cart button shortcode.
	 *
	 * @since 1.8.3
	 *
	 * @param array $atts
	 * @return void
	 */
	public function save_button_shortcode( $atts ) {
		// If current user has no access to share the cart then shortcode display nothing.
		if ( wcss_currnet_role_has_access() !== true ) {
			return;
		}

		$a = shortcode_atts(
			array(
				'text'      => esc_html( get_option( 'wcss_save_cart_button_text' ) ),
				'bgColor'   => esc_html( get_option( 'wcss_button_background_color' ) ),
				'textColor' => esc_html( get_option( 'wcss_button_text_color' ) ),
			),
			$atts
		);

		$style  = "background-color: {$a['bgColor']};";
		$style .= "color: {$a['textColor']};";

		return sprintf(
			'<a href="javascript:void( wcss.open_save_cart_popup() )" class="wcss-share-cart-btn-shortcode" style="%s">%s</a>',
			$style,
			esc_html( $a['text'] )
		);
	}

	/**
	 * Email cart button shortcode.
	 *
	 * @since 1.8.3
	 *
	 * @param array $atts
	 * @return void
	 */
	public function email_button_shortcode( $atts ) {
		// If current user has no access to share the cart then shortcode display nothing.
		if ( wcss_currnet_role_has_access() !== true ) {
			return;
		}

		$a = shortcode_atts(
			array(
				'text'      => esc_html__( 'Email Cart', 'woo-cart-share' ),
				'bgColor'   => esc_html( get_option( 'wcss_button_background_color' ) ),
				'textColor' => esc_html( get_option( 'wcss_button_text_color' ) ),
			),
			$atts
		);

		$style  = "background-color: {$a['bgColor']};";
		$style .= "color: {$a['textColor']};";

		return sprintf(
			'<a href="javascript:void( wcss.open_email_cart_popup() )" class="wcss-share-cart-btn-shortcode" style="%s">%s</a>',
			$style,
			esc_html( $a['text'] )
		);
	}

	/**
	 * Display saved cart.
	 *
	 * @since 1.9.1
	 *
	 * @return void
	 */
	public function saved_carts_display() {
		$current_user_id = get_current_user_id();
		$saved_carts     = wcss_get_saved_carts_by_user_id( $current_user_id );
		$saved_carts     = apply_filters( 'wcss_saved_cart_by_user', $saved_carts, $current_user_id );

		ob_start();

		if ( $saved_carts ) {
			wcss_get_template(
				'my-account/saved-cart-table.php',
				array(
					'saved_carts' => $saved_carts,
				)
			);
		} else {
			wcss_get_template(
				'my-account/empty-cart-message.php',
				array(
					'saved_carts' => $saved_carts,
				)
			);
		}

		return ob_get_clean();
	}

} // end of WCSS_Shortcodes

$wcss_shortcodes = new WCSS_Shortcodes();
