<?php
/**
 * EMail styles.
 *
 * @package WeCreativez\Templates
 * @version 1.0.0
 */

defined( 'ABSPATH' ) || exit;

// Load colors.
$email_bg_color    = get_option( 'wcss_email_background_color' );
$body_bg_color     = get_option( 'wcss_email_body_background_color' );
$header_bg_color   = get_option( 'wcss_email_header_background_color' );
$header_text_color = get_option( 'wcss_email_header_text_color' );
$button_bg_color   = get_option( 'wcss_email_button_background_color' );
$button_text_color = get_option( 'wcss_email_button_text_color' );

// !important; is a gmail hack to prevent styles being stripped if it doesn't like something.
// body{padding: 0;} ensures proper scale/positioning of the email in the iOS native email app.
?>
body {
	background-color: <?php echo esc_html( $email_bg_color ); ?>;
	padding-top: 80px;
	padding-bottom: 80px;
	padding-left: 10px;
	padding-right: 10px;
}

table {
	border-collapse: collapse;
	width: 100%;
}

dt,
dd {
	margin-top: 0;
	margin-bottom: 0;
	margin-left: 0;
	margin-right: 0;
}

ul {
	list-style: none;
	padding-top: 0;
	padding-bottom: 0;
	padding-left: 0;
	padding-right: 0;
	margin-top: 0;
	margin-bottom: 0;
	margin-left: 0;
	margin-right: 0;
}

li {
	padding-top: 0;
	padding-bottom: 0;
	padding-left: 0;
	padding-right: 0;
	margin-top: 0;
	margin-bottom: 0;
	margin-left: 0;
	margin-right: 0;
}

p {
	padding-top: 0;
	padding-bottom: 0;
	padding-left: 0;
	padding-right: 0;
	margin-top: 0;
	margin-bottom: 0;
	margin-left: 0;
	margin-right: 0;
}

a {
	text-decoration: none;
	color: #263238;
}

#wrapper {
	width: 690px;
	padding-left: 0;
	padding-right: 0;
	font-size: 15px;
	font-family: Arial, sans-serif;
	line-height: 1.4em;
	letter-spacing: -0.03em;
	margin-top: 0;
	margin-bottom: 0;
	margin-left: auto;
	margin-right: auto;
	background-color: <?php echo esc_html( $body_bg_color ); ?>;
	color: #444;
}

#header,
#footer {
	background-color: <?php echo esc_html( $header_bg_color ); ?>;
	text-align: center;
	padding-top: 15px;
	padding-bottom: 15px;
	padding-left: 15px;
	padding-right: 15px;
}

#header .logo {
	max-width: 240px;
	width: auto;
	height: auto;
}

#header .brand-name,
#footer .brand-name {
	font-size: 21px;
	display: inline-block;
	color: <?php echo esc_html( $header_text_color ); ?>;
	text-decoration: none;
}

#footer .brand-name {
	font-size: 15px;
}

.description {
	padding-left: 15px;
	padding-right: 15px;
	text-align: center;
}

#retrieve-cart .button {
	padding-top: 10px;
	padding-bottom: 10px;
	padding-left: 40px;
	padding-right: 40px;
	display: inline-block;
	background-color: <?php echo esc_html( $button_bg_color ); ?>;
	color: <?php echo esc_html( $button_text_color ); ?>;
	text-decoration: none;
	border-radius: 4px;
	border: 1px solid <?php echo esc_html( $button_bg_color ); ?>;
}

#retrieve-cart .link {
	text-decoration: none;
	color: #263238;
}

#products {
	margin-top: 20px;
	margin-bottom: 20px;
}

#products thead th,
#products tbody td {
	padding-top: 10px;
	padding-bottom: 10px;
	padding-left: 15px;
	padding-right: 15px;
}

#products tbody td {
	border-top: 1px solid #eeeeee;
}

#products thead .heading-name,
#products tbody .name {
	text-align: left;
}

#products thead .heading-price,
#products tbody .price,
#products thead .heading-qty,
#products tbody .qty,
#products thead .heading-subtotal,
#products tbody .subtotal {
	text-align: right;
}

#products tbody .image {
	width: 80px;
}

#products tbody .image img {
	width: 100%;
	height: auto;
}

#cart-totals th,
#cart-totals td {
	padding-top: 10px;
	padding-bottom: 10px;
	padding-left: 15px;
	padding-right: 15px;
	text-align: left;
	border-top: 1px solid #eeeeee;
}

#cart-totals th,
#cart-totals td {
	background-color: #f5f5f5;
}

#footer .follow-us {
	text-align: center;
}

#footer .follow-us li {
	display: inline-block;
	margin-top: 15px;
	margin-bottom: 15px;
	margin-left: 15px;
	margin-right: 15px;
}

#footer .follow-us li a {
	text-decoration: none;
}

/* RTL */
.rtl {
	direction: rtl;
}

.rtl #products thead .heading-name,
.rtl #products tbody .name {
	text-align: right;
}

.rtl #products thead .heading-price,
.rtl #products tbody .price,
.rtl #products thead .heading-qty,
.rtl #products tbody .qty,
.rtl #products thead .heading-subtotal,
.rtl #products tbody .subtotal {
	text-align: left;
}

.rtl #cart-totals th,
.rtl #cart-totals td {
	text-align: right;
}
