<?php
/**
 * Cart products.
 *
 * @package WeCreativez\Templates
 * @version 1.0.0
 */

defined( 'ABSPATH' ) || exit;
?>
<div class="wcss-container">

	<?php do_action( 'wcss_before_print_cart' ); ?>

	<?php if ( ! WC()->cart->is_empty() ) : ?>
	<table class="wcss-cart-products">

		<thead>
			<tr>
				<th class="wcss-cart-products-heading__image"></th>
				<th class="wcss-cart-products-heading__name"><?php esc_html_e( 'Product', 'woo-cart-share' ); ?></th>
				<th class="wcss-cart-products-heading__price"><?php esc_html_e( 'Price', 'woo-cart-share' ); ?></th>
				<th class="wcss-cart-products-heading__qty"><?php esc_html_e( 'Quantity', 'woo-cart-share' ); ?></th>
				<th class="wcss-cart-products-heading__subtotal"><?php esc_html_e( 'Subtotal', 'woo-cart-share' ); ?></th>
			</tr>
		</thead>

		<tbody>
		<?php
		foreach ( WC()->cart->get_cart() as $cart_item_key => $cart_item ) {
			$_product   = apply_filters( 'woocommerce_cart_item_product', $cart_item['data'], $cart_item, $cart_item_key );
			$product_id = apply_filters( 'woocommerce_cart_item_product_id', $cart_item['product_id'], $cart_item, $cart_item_key );

			if ( $_product && $_product->exists() && $cart_item['quantity'] > 0 && apply_filters( 'woocommerce_cart_item_visible', true, $cart_item, $cart_item_key ) ) {
				$product_permalink = apply_filters( 'woocommerce_cart_item_permalink', $_product->is_visible() ? $_product->get_permalink( $cart_item ) : '', $cart_item, $cart_item_key );
				?>
				<tr class="wcss-cart-product">
					<td class="wcss-cart-product__image">
						<?php
						$thumbnail = apply_filters( 'woocommerce_cart_item_thumbnail', $_product->get_image(), $cart_item, $cart_item_key );

						if ( 'yes' === get_option( 'wcss_print_cart_remove_product_link' ) ) {
							echo $thumbnail; // PHPCS: XSS ok.
						} else {
							printf( '<a href="%s">%s</a>', esc_url( $product_permalink ), $thumbnail ); // PHPCS: XSS ok.
						}
						?>
					</td>
					<td class="wcss-cart-product__name">
						<?php
							if ( 'yes' === get_option( 'wcss_print_cart_remove_product_link' ) ) {
								echo wp_kses_post( apply_filters( 'woocommerce_cart_item_name', $_product->get_name(), $cart_item, $cart_item_key ) . '&nbsp;' );
							} else {
								echo wp_kses_post( apply_filters( 'woocommerce_cart_item_name', sprintf( '<a href="%s">%s</a>', esc_url( $product_permalink ), $_product->get_name() ), $cart_item, $cart_item_key ) );
							}

							do_action( 'woocommerce_after_cart_item_name', $cart_item, $cart_item_key );

							// Meta data.
							echo wc_get_formatted_cart_item_data( $cart_item ); // PHPCS: XSS ok.

							// Backorder notification.
							if ( $_product->backorders_require_notification() && $_product->is_on_backorder( $cart_item['quantity'] ) ) {
								echo wp_kses_post( apply_filters( 'woocommerce_cart_item_backorder_notification', '<p class="backorder_notification">' . esc_html__( 'Available on backorder', 'woo-cart-share' ) . '</p>', $product_id ) );
							}
						?>
					</td>
					<td class="wcss-cart-product__price">
						<?php
							echo apply_filters( 'woocommerce_cart_item_price', WC()->cart->get_product_price( $_product ), $cart_item, $cart_item_key ); // PHPCS: XSS ok.
						?>
					</td>
					<td class="wcss-cart-product__qty">
						<?php
							echo absint( $cart_item['quantity'] );
						?>
					</td>
					<td class="wcss-cart-product__subtotal">
						<?php
							echo apply_filters( 'woocommerce_cart_item_subtotal', WC()->cart->get_product_subtotal( $_product, $cart_item['quantity'] ), $cart_item, $cart_item_key ); // PHPCS: XSS ok.
						?>
					</td>
				</tr>
				<?php
			}
		}
		?>
		</tbody>

	</table>
	<?php endif; ?>

</div>
